"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const hangouts_chat_webhook_1 = require("hangouts-chat-webhook");
class Converter {
    static convert(slack) {
        const message = new hangouts_chat_webhook_1.Message();
        if (!slack.attachments && slack.text) {
            message.setText(slack.text);
        }
        else if (slack.attachments) {
            message.setPreviewText(slack.text);
            if (slack.username) {
                message.setSender(new hangouts_chat_webhook_1.User().setDisplayName(slack["username"]));
            }
            slack.attachments.forEach(attachment => {
                const header = new hangouts_chat_webhook_1.CardHeader()
                    .setTitle(attachment["title"]);
                if (attachment.fallback) {
                    message.setFallbackText(message.getFallbackText() ? attachment.fallback + "\n" : attachment.fallback);
                    message.setPreviewText(message.getFallbackText().trim());
                }
                if (attachment.pretext) {
                    header.setSubtitle(attachment.pretext);
                }
                const card = new hangouts_chat_webhook_1.Card()
                    .setHeader(header);
                const section = new hangouts_chat_webhook_1.Section();
                if (attachment.author_name) {
                    section.addWidget(Converter.author(attachment));
                }
                if (attachment.image_url) {
                    section.addWidget(Converter.image(attachment));
                }
                if (attachment.text) {
                    section.addWidget(Converter.text(attachment));
                }
                if (attachment.fields) {
                    attachment.fields.forEach(field => {
                        section.addWidget(Converter.field(field));
                    });
                }
                if (attachment.footer) {
                    section.addWidget(Converter.footer(attachment));
                }
                if (attachment.title_link) {
                    section.addWidget(Converter.bottomLink(attachment));
                }
                message.addCard(card.addSection(section));
            });
        }
        return message;
    }
    static image(attachment) {
        return new hangouts_chat_webhook_1.WidgetMarkup()
            .setImage(new hangouts_chat_webhook_1.Image()
            .setImageUrl(attachment["image_url"]));
    }
    static formatText(text) {
        const match = /^>>>([\s\S]*)/gm.exec(text);
        if (match && match.length > 0) {
            text = text.replace(match[0], match[1]
                .trim()
                .replace(/\n/g, "\n" + '<font color="#e3e4e6">┃</font> '));
        }
        return text
            .replace(/\*(.+?)\*/g, "<b>$1</b>")
            .replace(/_(.+?)_/g, "<i>$1</i>")
            .replace(/~(.+?)~/g, "<strike>$1</strike>")
            .replace(/```(.+?)```/g, "<font color=\"#424242\">$1</font>")
            .replace(/^>(.+?)/gm, "<font color=\"#e3e4e6\">┃</font> $1")
            .replace(/`(.+?)`/g, "<font color=\"#d72b3f\">$1</font>")
            .trim();
    }
    static text(attachment) {
        let color;
        if (attachment.color) {
            let hex = attachment.color;
            if (attachment.color == "danger") {
                hex = "#a30200";
            }
            else if (attachment.color == "warning") {
                hex = "#daa038";
            }
            else if (attachment.color == "good") {
                hex = "#2eb886";
            }
            else if (attachment.color.substr(0, 1) != "#") {
                hex = "#e8e8e8";
            }
            color = '<font color="' + hex + '"><b>▮</b></font> ';
        }
        return new hangouts_chat_webhook_1.WidgetMarkup()
            .setTextParagraph(new hangouts_chat_webhook_1.TextParagraph()
            .setText(color + Converter.formatText(attachment.text)));
    }
    static author(attachment) {
        const widget = new hangouts_chat_webhook_1.WidgetMarkup();
        let onclick;
        if (attachment.author_link) {
            onclick = new hangouts_chat_webhook_1.OnClick()
                .setOpenLink(new hangouts_chat_webhook_1.OpenLink()
                .setUrl(attachment.author_link));
        }
        if (attachment.author_icon) {
            widget.addButton(new hangouts_chat_webhook_1.Button()
                .setImageButton(new hangouts_chat_webhook_1.ImageButton()
                .setIconUrl(attachment.author_icon)
                .setName(attachment.author_name)
                .setOnClick(onclick)));
        }
        widget.addButton(new hangouts_chat_webhook_1.Button()
            .setTextButton(new hangouts_chat_webhook_1.TextButton()
            .setText(attachment.author_name)
            .setOnClick(onclick)));
        return widget;
    }
    static field(field) {
        return new hangouts_chat_webhook_1.WidgetMarkup()
            .setKeyValue(new hangouts_chat_webhook_1.KeyValue()
            .setTopLabel(field["title"])
            .setContent(field["value"])
            .setContentMultiline(!field["short"])
            .setIcon(hangouts_chat_webhook_1.Icon.DESCRIPTION));
    }
    static footer(attachment) {
        const footerLink = new hangouts_chat_webhook_1.OnClick();
        if (attachment.title_link) {
            footerLink.setOpenLink(new hangouts_chat_webhook_1.OpenLink()
                .setUrl(attachment.title_link));
        }
        const footer = new hangouts_chat_webhook_1.WidgetMarkup();
        if (attachment.footer_icon) {
            footer.addButton(new hangouts_chat_webhook_1.Button()
                .setImageButton(new hangouts_chat_webhook_1.ImageButton()
                .setIconUrl(attachment.footer_icon)
                .setName(attachment.footer)
                .setOnClick(footerLink)));
        }
        footer.addButton(new hangouts_chat_webhook_1.Button()
            .setTextButton(new hangouts_chat_webhook_1.TextButton()
            .setText(attachment.footer)
            .setOnClick(footerLink)));
        return footer;
    }
    static bottomLink(attachment) {
        return new hangouts_chat_webhook_1.WidgetMarkup()
            .addButton(new hangouts_chat_webhook_1.Button()
            .setTextButton(new hangouts_chat_webhook_1.TextButton()
            .setText("Open")
            .setOnClick(new hangouts_chat_webhook_1.OnClick()
            .setOpenLink(new hangouts_chat_webhook_1.OpenLink().
            setUrl(attachment.title_link)))));
    }
}
exports.Converter = Converter;
//# sourceMappingURL=converter.js.map