"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const url_1 = __importDefault(require("url"));
const express_1 = __importDefault(require("express"));
const compression_1 = __importDefault(require("compression"));
const body_parser_1 = __importDefault(require("body-parser"));
const winston_1 = __importDefault(require("winston"));
const express_winston_1 = __importDefault(require("express-winston"));
const errorhandler_1 = __importDefault(require("errorhandler"));
const webhook_1 = require("./webhook");
exports.app = express_1.default();
exports.app.set("port", process.env.PORT || 3000);
// request
exports.app.use(compression_1.default());
exports.app.use(body_parser_1.default.json());
exports.app.use(body_parser_1.default.urlencoded({ extended: true }));
// logger
exports.app.use((req, res, next) => {
    Object.assign(res.locals, {
        logUrl: url_1.default.parse(req.url).pathname
    });
    next();
});
const logger = winston_1.default.createLogger({
    transports: [
        new winston_1.default.transports.Console({})
    ],
    format: winston_1.default.format.combine(winston_1.default.format.splat(), winston_1.default.format.colorize({}), winston_1.default.format.timestamp(), winston_1.default.format.printf(info => {
        let meta = "";
        if (info.meta && exports.app.get("env") == "development") {
            meta = JSON.stringify(info.meta || {}, undefined, 4);
        }
        return `${info.timestamp} ${info.level}: ${info.message} ${meta}`;
    })),
});
exports.app.use(express_winston_1.default.logger({
    winstonInstance: logger,
    msg: "{{req.method}} {{res.locals.logUrl}} {{res.statusCode}} {{res.responseTime}}ms",
    colorize: true,
}));
// router
exports.app.use(express_1.default.static("public"));
exports.app.post("/:space", webhook_1.Webhook.express);
// errors
exports.app.use(express_winston_1.default.errorLogger({
    winstonInstance: logger,
    msg: "{{req.method}} {{res.locals.logUrl}} {{res.statusCode}} {{err.message}}"
}));
exports.app.use(errorhandler_1.default({ log: false }));
// docker exit
process.on("SIGINT", function () {
    process.exit();
});
// listen
exports.app.listen(exports.app.get("port"), () => {
    logger.info("App is running at http://localhost:%d in %s mode", exports.app.get("port"), exports.app.get("env"));
});
//# sourceMappingURL=server.js.map