"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const url = __importStar(require("url"));
const superagent = __importStar(require("superagent"));
const converter_1 = require("./converter");
class WebhookResponse {
    constructor(status, headers, body) {
        this.status = status;
        this.headers = headers;
        this.body = body;
    }
}
exports.WebhookResponse = WebhookResponse;
class WebhookError {
    constructor(status, headers, body, error) {
        this.status = status;
        this.headers = headers;
        this.body = body;
        this.error = error;
    }
}
exports.WebhookError = WebhookError;
class Webhook {
    static send(space, key, token, body) {
        return new Promise((resolve, reject) => {
            const webhookUrl = "https://chat.googleapis.com/v1/spaces/" + space + "/messages?key=" + key + "&token=" + token;
            superagent.post(webhookUrl)
                .set("Content-Type", "application/json; charset=UTF-8")
                .send(converter_1.Converter.convert(body))
                .then((response) => {
                resolve(new WebhookResponse(response.status, response.header, response.body));
            })
                .catch((err) => {
                reject(new WebhookError(err.status, err.header, err.body, err.response && err.response.text ? JSON.parse(err.response.text) : "Request failed"));
            });
        });
    }
    static express(req, res, next) {
        const parsed = url.parse(req.url, true);
        Webhook.send(req.params["space"], parsed.query.key, parsed.query.token, req.body)
            .then((value) => res
            .status(value.status)
            .json(value))
            .catch((reason) => {
            if (!(reason instanceof WebhookError)) {
                return next(reason);
            }
            return res
                .status(reason.status)
                .json(reason);
        });
    }
    static azure(context, req) {
        return __awaiter(this, void 0, void 0, function* () {
            const parsed = url.parse(req.url, true);
            req.url = "http://localhost/" + req.query.space + req.url.substring(req.url.indexOf("?"));
            req.params = req.query;
            parsed.pathname = "/" + parsed.query.space;
            delete parsed.query.space;
            delete parsed.query.code;
            delete parsed.search;
            delete parsed.href;
            delete parsed.path;
            try {
                const value = yield Webhook.send(parsed.query.space, parsed.query.key, parsed.query.token, req.body);
                context.res = {
                    status: value.status,
                    headers: {
                        "Content-Type": "application/json; charset=UTF-8"
                    },
                    body: value
                };
            }
            catch (reason) {
                if (!(reason instanceof WebhookError)) {
                    context.res = {
                        status: 500,
                        body: reason.message
                    };
                }
                else {
                    context.res = {
                        status: reason.status,
                        headers: {
                            "Content-Type": "application/json; charset=UTF-8"
                        },
                        body: reason
                    };
                }
            }
        });
    }
    ;
}
exports.Webhook = Webhook;
//# sourceMappingURL=webhook.js.map